# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django import forms
from django.contrib import admin
from django.contrib.auth import get_user_model
from django.contrib.auth.forms import UserChangeForm, UserCreationForm
from django.utils.translation import ugettext_lazy as _
from django.contrib.auth.admin import UserAdmin
from email_auth.models import User


class EmailUserCreationForm(UserCreationForm):
    class Meta(UserChangeForm.Meta):
        model = get_user_model()

    def save(self, commit=True):
        self.instance.is_staff = True
        self.instance.username = self.instance.email
        return super(EmailUserCreationForm, self).save(commit=False)


class EmailUserChangeForm(UserChangeForm):
    email = forms.EmailField(required=False)

    class Meta(UserChangeForm.Meta):
        model = get_user_model()

    def __init__(self, *args, **kwargs):
        initial = kwargs.get('initial', {})
        instance = kwargs.get('instance')
        initial['email'] = instance.email or ''
        super(EmailUserChangeForm, self).__init__(initial=initial, *args, **kwargs)

    def clean_email(self):
        # nullify empty email field in order to prevent unique index collisions
        return self.cleaned_data.get('email').strip() or None

    def save(self, commit=False):
        self.instance.email = self.cleaned_data['email']
        self.instance.username = self.instance.email
        return super(EmailUserChangeForm, self).save(commit)


@admin.register(User)
class EmailUserAdmin(UserAdmin):
    list_display = ('email', 'full_name', 'is_staff')
    list_display_links = ('email', 'full_name')
    readonly_fields = ('last_login', 'date_joined',)
    form = EmailUserChangeForm
    add_form = EmailUserCreationForm

    fieldsets = (
        (None, {'fields': ('email', 'password', ('last_name', 'first_name', 'middle_name'))}),
        (_('Permissions'), {'fields': ('is_active', 'is_staff', 'is_superuser',
                                       'groups', 'user_permissions')}),
        (_('Important dates'), {'fields': ('last_login', 'date_joined')}),
    )

    add_fieldsets = (
        (None, {
            'classes': ('wide',),
            'fields': ('email', 'password1', 'password2')
        }),
    )

    def full_name(self, obj):
        return obj.get_full_name()
    full_name.short_description = 'Полное имя'
